pub struct PageInfo {
pub current: Option<Data>,
pub history: BTreeMap<u64, Data>,
pub usage: u64,
pub hx: u32,
}Expand description
Information for a page, including historic data.
Fields
current: Option<Data>Current data for the page( None implies it is stored in underlying file ).
history: BTreeMap<u64, Data>Historic data for the page. Has data for page at specified time. A copy is made prior to an update, so get looks forward from access time.
usage: u64How many times has the page been used.
hx: u32Heap index.