pub type HashMap<K, V> = HashMap<K, V, FxBuildHasher>;Expand description
Type alias for a hash map that uses the Fx hashing algorithm.
Aliased Type
pub struct HashMap<K, V> { /* private fields */ }pub type HashMap<K, V> = HashMap<K, V, FxBuildHasher>;Type alias for a hash map that uses the Fx hashing algorithm.
pub struct HashMap<K, V> { /* private fields */ }