pub type HashSet<V> = HashSet<V, FxBuildHasher>;Expand description
Type alias for a hash set that uses the Fx hashing algorithm.
Aliased Type
pub struct HashSet<V> { /* private fields */ }pub type HashSet<V> = HashSet<V, FxBuildHasher>;Type alias for a hash set that uses the Fx hashing algorithm.
pub struct HashSet<V> { /* private fields */ }